/**
  *  \file client/mainopts.h
  *
  *  (c) 2001-2021 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_MAINOPTS_H
#define PCC_V2_CLIENT_MAINOPTS_H

#include "util/cmdline.h"

/** Option Parser for pcc-v2. */
class PCC2OptionParser : public StandardCommandLineParser {
 public:
    enum Mode {
        mUnset,                 // Mode not set
        mPlay,                  // We want to play
        mDefault,               // Play if unique, otherwise chooser
        mChooseGame             // Choose directory
    };
    
    PCC2OptionParser();
    void     handleNonoption(const string_t& str);
    void     handleError(const string_t& msg);
    int      getNumNonoptions() const;
    void     parseFinished();
    void     setMode(Mode m);

    string_t getGameDirName() const;
    string_t getRootDirName() const;
    int      getPlayerId() const;
    Mode     getMode() const;

    void     setGameDirName(string_t gd);
    void     setPlayerId(int pid);

 private:
    enum {
        MAX_NON_OPTIONS = 2
    };
    int num_nonoptions;
    int player;
    string_t nonopts[MAX_NON_OPTIONS];
    Mode mode;

    static void help(StandardCommandLineParser&, const Option&);
    static void setCharset(StandardCommandLineParser&, const Option&);
    static void setDirectoryMode(StandardCommandLineParser&, const Option&);
};

inline int
PCC2OptionParser::getNumNonoptions() const
{
    return num_nonoptions;
}

inline void
PCC2OptionParser::setMode(Mode m)
{
    this->mode = m;
}

inline string_t
PCC2OptionParser::getGameDirName() const
{
    return nonopts[0];
}

inline string_t
PCC2OptionParser::getRootDirName() const
{
    return nonopts[1];
}

inline int
PCC2OptionParser::getPlayerId() const
{
    return player;
}

inline PCC2OptionParser::Mode
PCC2OptionParser::getMode() const
{
    return mode;
}

inline void
PCC2OptionParser::setGameDirName(string_t gd)
{
    nonopts[0] = gd;
}

inline void
PCC2OptionParser::setPlayerId(int pid)
{
    player = pid;
}

#endif
