/**
  *  \file client/widgets/msgfilter.cc
  *  \brief Message Filter Control Widget
  *
  *  (c) 2001-2021 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/msgfilter.h"
#include "ui/uiglobal.h"
#include "util/nls.h"
#include "game/pref.h"
#include "client/dlg-subject.h"

WMessageFilterControl::WMessageFilterControl(WSubjectList& sublist)
    : btn_o(0, "O", 'o'),
      btn_k(0, "K", 'k'),
      sublist(sublist)
{
    init();
}

WMessageFilterControl::~WMessageFilterControl()
{ }

void
WMessageFilterControl::init()
{
    const int x = getExtent().x;
    const int y = getExtent().y;
    const int h = font_heights[FONT_NORMAL];
    const int m = font_ems[FONT_NORMAL];

    btn_o.addCall(this, &WMessageFilterControl::onOldToggle);
    btn_o.setState(UIButton::bf_SmallSize, true);
    btn_k.addCall(this, &WMessageFilterControl::onKillToggle);
    btn_k.setState(UIButton::bf_SmallSize, true);
    
    add(btn_k, GfxRect(x,           y, h-1, h-1));
    add(btn_o, GfxRect(x+h+10*m+10, y, h-1, h-1));

    conn_sublist = observe(sublist.sig_moved);
}

void
WMessageFilterControl::drawContent(GfxCanvas& can)
{
    const int x = getExtent().x;
    const int y = getExtent().y;
    const int h = font_heights[FONT_NORMAL];
    const int m = font_ems[FONT_NORMAL];

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.useColorScheme(getSkin());
    ctx.setSolidBackground();
    ctx.setColor(UIColor::tc_Static);

    const char* txt;
    txt = (sublist.isSelectedMessageFiltered() ? _("Filtered: yes") : _("Filtered: no"));
    outTextF(ctx, x+h+5, y, 10*m, txt);

    txt = (getUserPreferences().CollapseOldMessages() ? _("Old messages: one line") : _("Old messages: normal"));
    const int dx = 2*h+10*m+15;
    outTextF(ctx, x+dx, y, getExtent().w-dx, txt);

    can.update(getExtent());
}

void
WMessageFilterControl::getLayoutInfo(LayoutInfo& info)
{
    const int h = font_heights[FONT_NORMAL];
    const int m = font_ems[FONT_NORMAL];
    info.pref_size = info.min_size = GfxPoint(2*h + 25*m + 20, h);
    info.flags = li_FlexibleH;
}

void
WMessageFilterControl::onOldToggle()
{
    GUserPreferences& pref = getUserPreferences();
    pref.CollapseOldMessages.set(!pref.CollapseOldMessages());
    sublist.regenerate();
    drawWidget();
}

void
WMessageFilterControl::onKillToggle()
{
    sublist.toggleFilterSelectedMessage();
    drawWidget();
}
