/**
  *  \file game/shiptype.h
  *  \brief Starship Object Types
  *
  *  (c) 2001-2021 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_SHIPTYPE_H
#define PCC_V2_GAME_SHIPTYPE_H

#include "game/objtypes.h"
#include "game/ship.h"

/** Played starships type. Contains all starships the player can play. */
class GPlayedShipType : public GIndexedObjectType {
 public:
    GPlayedShipType(GUniverse& univ);
    GShip& getObjectByIndex(int index);
    GUniverse* getUniverseByIndex(int index);
    bool isValidIndex(int index) const;

 private:
    GUniverse& univ;
};

/** Any starships type. Contains all starships. */
class GAnyShipType : public GIndexedObjectType {
 public:
    GAnyShipType(GUniverse& univ);
    GShip& getObjectByIndex(int index);
    GUniverse* getUniverseByIndex(int index);
    bool isValidIndex(int index) const;

 private:
    GUniverse& univ;
};

/** History starships type. Contains all starships that have history (even if they
    are not visible now). */
class GHistoryShipType : public GIndexedObjectType {
 public:
    GHistoryShipType(GUniverse& univ);
    GShip& getObjectByIndex(int index);
    GUniverse* getUniverseByIndex(int index);
    bool isValidIndex(int index) const;

 private:
    GUniverse& univ;
};

#endif
