/**
  *  \file int/if/ifutil.h
  *  \brief Interpreter Game Interface: Utilities
  *
  *  (c) 2001-2021 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_IF_IFUTIL_H
#define PCC_V2_INT_IF_IFUTIL_H

#include "cpluslib/types.h"
#include "cpluslib/string.h"

class IntValue;
class GCargoSpec;
class IntNameQuery;

/** Name mapping. */
struct TIntMapping {
    const char* name;          /**< Name of property. */
    uint16_t    index;         /**< Index of property. */
    uint8_t     domain;        /**< Domain of property. */
    uint8_t     type;
};

/** Type. This is a hint for reflection, not an unconditional promise,
    that is, code generation may not rely on it, and all code must
    handle receiving a "wrong" value. However, it is intended to be
    close. */
enum TIntTypeHint {
    thNone,
    thBool,
    thInt,
    thFloat,
    thString,
    thProcedure,
    thFunction,
    thArray
};

int32_t lookupName(const IntNameQuery& name, const TIntMapping* mapping, uint32_t size);

bool checkIntArg(int32_t& out, IntValue* value);
bool checkIntArg(int32_t& out, IntValue* value, int32_t min, int32_t max);
bool checkBoolArg(bool& out, IntValue* value);
bool checkStringArg(string_t& out, IntValue* value);
bool checkFlagArg(int32_t& flagOut, int32_t* valueOut, IntValue* value, const char* tpl);
bool checkCargoSpecArg(GCargoSpec& out, IntValue* value);

template<typename T>
static IntValue*
makeIntFromMaybe(T value)
{
    if (value.isKnown())
        return makeIntValue(value);
    else
        return 0;
}

#endif
